@@ -38,7 +38,7 @@ from pixelfunc import (ma, mask_good, mask_bad,
                        nside2npix, npix2nside, 
                        isnsideok, isnpixok,
                        ring2nest, nest2ring, reorder,
-                       get_neighbours, get_all_neighbours, get_interp_val,
+                       get_neighbours, get_all_neighbours, max_pixrad, get_interp_val,
                        fit_dipole, fit_monopole,
                        remove_dipole, remove_monopole,
                        get_nside, maptype, ud_grade, nside2resol, nside2pixarea,
@@ -47,14 +47,18 @@ from pixelfunc import (ma, mask_good, mask_bad,
 from sphtfunc import (anafast, map2alm,
                       alm2map, Alm, synalm, synfast,
                       smoothing, smoothalm, almxfl, alm2cl,
-                      pixwin, alm2map_der1)
+                      pixwin, alm2map_der1, gauss_beam)
+from _sphtools import rotate_alm
 
 try:
-    from _query_disc import query_disc, query_strip, query_polygon
+    from _query_disc import query_disc, query_strip, query_polygon, boundaries
 except ImportError:
     warnings.warn('Warning: cannot import query disc module')
+try:
+    from _pixelfunc import ringinfo, pix2ring
+except ImportError:
+    warnings.warn('Warning: cannot import pixelfunc module')
 
-from zoomtool import mollzoom,set_g_clim
 
 from rotator import Rotator, vec2dir, dir2vec
 
@@ -73,6 +77,7 @@ except ImportError:
 try:
     from visufunc import (mollview,graticule,delgraticules,gnomview,
                           projplot,projscatter, projtext, cartview)
+    from zoomtool import mollzoom,set_g_clim
     if visufunc.matplotlib.__version__ == '0.98,3':
         warnings.warn("Bug in matplotlib 0.98.3 prevents mollview from working\n"+
                       "You should upgrade to matplotlib 0.98.4 or above",
